function [X_norm, mu, sigma] = featureNormalize(X)
%FEATURENORMALIZE Normalizes the features in X 
%   FEATURENORMALIZE(X) returns a normalized version of X where
%   the mean value of each feature is 0 and the standard deviation
%   is 1. This is often a good preprocessing step to do when
%   working with learning algorithms.

% You need to set these values correctly
X_norm = X;
mu = zeros(1, size(X, 2));
sigma = zeros(1, size(X, 2));

% ====================== YOUR CODE HERE ======================
% Instructions: First, for each feature dimension, compute the mean
%               of the feature and subtract it from the dataset,
%               storing the mean value in mu. Next, compute the 
%               standard deviation of each feature and divide
%               each feature by it's standard deviation, storing
%               the standard deviation in sigma. 
%
%               Note that X is a matrix where each column is a 
%               feature and each row is an example. You need 
%               to perform the normalization separately for 
%               each feature. 
%
% Hint: You might find the 'mean' and 'std' functions useful.
%       

% Get the number of columns in X
numcolumns = size(X, 2);

% For each column in x
for i = 1:numcolumns

	% calculate the mean value of this column
	themean = mean(X(:,i));
	
	% calculate the standard deviation of this column
	thestd = std(X(:,i));
	
	% normalize each element in this column by subtracting MV and dividing by SD
	X_norm(:,i) = X_norm(:,i) .- themean;
	X_norm(:,i) = X_norm(:,i) ./ thestd;
	
	% update mu at this column
	mu(:,i) = themean;
	
	% update sigma at this column
	sigma(:,i) = thestd;

	end % End of for loop






% ============================================================

end
